@@ -32,7 +32,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 sub db {
   my $self = shift;
@@ -116,12 +116,13 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   $db->query('insert into names (name) values (?)', 'Stefan');
 
   # Insert more rows in a transaction
-  {
+  eval {
     my $tx = $db->begin;
     $db->query('insert into names (name) values (?)', 'Baerbel');
     $db->query('insert into names (name) values (?)', 'Wolfgang');
     $tx->commit;
   };
+  say $@ if $@;
 
   # Insert another row and return the generated id
   say $db->query('insert into names (name) values (?) returning id', 'Daniel')
@@ -255,7 +256,7 @@ L<Mojo::Pg::Migrations> object you can use to change your database schema more
 easily.
 
   # Load migrations from file and migrate to latest version
-  $pg->migrations->from_file('/Users/sri/migrations.sql')->migrate;
+  $pg->migrations->from_file('/home/sri/migrations.sql')->migrate;
 
 =head2 options
 
